# hagerstrand


[![image](https://img.shields.io/pypi/v/hagerstrand.svg)](https://pypi.python.org/pypi/hagerstrand)


**A Python package for an interactive space-time Geographic Information System (GIS)**


-   Free software: MIT license
-   Documentation: https://jimmy-feng.github.io/hagerstrand
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
